#!/usr/bin/env python

# Configuration
gameMusic = False
gameSound = False
player_speed = 8
enemy_speed = 6
players = 1
lives = 2

# Game state
boss = 0
greenScore = 0
purpleScore = 0
greenHits = 0
purpleHits = 0
greenPoints = 0
purplePoints = 0
greenHitsTotal = 0
purpleHitsTotal = 0
currentLvl = 0
areMonstersEvil = False
levelselect = 0
